==> certmanager-model-v1alpha2-6.4.1-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VenafiTPPFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VenafiTPPFluentImpl<A extends VenafiTPPFluent<A>> extends BaseFluent<A> implements VenafiTPPFluent<A>{
  public VenafiTPPFluentImpl() {
  }
  public VenafiTPPFluentImpl(VenafiTPP instance) {
    this.withCaBundle(instance.getCaBundle()); 
    this.withCredentialsRef(instance.getCredentialsRef()); 
    this.withUrl(instance.getUrl()); 
  }
  private String caBundle;
  private LocalObjectReferenceBuilder credentialsRef;
  private String url;
  public String getCaBundle() {
    return this.caBundle;
  }
  public A withCaBundle(String caBundle) {
    this.caBundle=caBundle; return (A) this;
  }
  public Boolean hasCaBundle() {
    return this.caBundle != null;
  }
  
  /**
   * This method has been deprecated, please use method buildCredentialsRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getCredentialsRef() {
    return this.credentialsRef!=null ?this.credentialsRef.build():null;
  }
  public LocalObjectReference buildCredentialsRef() {
    return this.credentialsRef!=null ?this.credentialsRef.build():null;
  }
  public A withCredentialsRef(LocalObjectReference credentialsRef) {
    _visitables.get("credentialsRef").remove(this.credentialsRef);
    if (credentialsRef!=null){ this.credentialsRef= new LocalObjectReferenceBuilder(credentialsRef); _visitables.get("credentialsRef").add(this.credentialsRef);} else { this.credentialsRef = null; _visitables.get("credentialsRef").remove(this.credentialsRef); } return (A) this;
  }
  public Boolean hasCredentialsRef() {
    return this.credentialsRef != null;
  }
  public A withNewCredentialsRef(String name) {
    return (A)withCredentialsRef(new LocalObjectReference(name));
  }
  public VenafiTPPFluent.CredentialsRefNested<A> withNewCredentialsRef() {
    return new VenafiTPPFluentImpl.CredentialsRefNestedImpl();
  }
  public VenafiTPPFluent.CredentialsRefNested<A> withNewCredentialsRefLike(LocalObjectReference item) {
    return new VenafiTPPFluentImpl.CredentialsRefNestedImpl(item);
  }
  public VenafiTPPFluent.CredentialsRefNested<A> editCredentialsRef() {
    return withNewCredentialsRefLike(getCredentialsRef());
  }
  public VenafiTPPFluent.CredentialsRefNested<A> editOrNewCredentialsRef() {
    return withNewCredentialsRefLike(getCredentialsRef() != null ? getCredentialsRef(): new LocalObjectReferenceBuilder().build());
  }
  public VenafiTPPFluent.CredentialsRefNested<A> editOrNewCredentialsRefLike(LocalObjectReference item) {
    return withNewCredentialsRefLike(getCredentialsRef() != null ? getCredentialsRef(): item);
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VenafiTPPFluentImpl that = (VenafiTPPFluentImpl) o;
    if (caBundle != null ? !caBundle.equals(that.caBundle) :that.caBundle != null) return false;
    if (credentialsRef != null ? !credentialsRef.equals(that.credentialsRef) :that.credentialsRef != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caBundle,  credentialsRef,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (caBundle != null) { sb.append("caBundle:"); sb.append(caBundle + ","); }
    if (credentialsRef != null) { sb.append("credentialsRef:"); sb.append(credentialsRef + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  class CredentialsRefNestedImpl<N> extends LocalObjectReferenceFluentImpl<VenafiTPPFluent.CredentialsRefNested<N>> implements VenafiTPPFluent.CredentialsRefNested<N>,Nested<N>{
    CredentialsRefNestedImpl(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    CredentialsRefNestedImpl() {
      this.builder = new LocalObjectReferenceBuilder(this);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) VenafiTPPFluentImpl.this.withCredentialsRef(builder.build());
    }
    public N endCredentialsRef() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VenafiTPPFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VenafiTPPFluentImpl<A extends VenafiTPPFluent<A>> extends BaseFluent<A> implements VenafiTPPFluent<A>{
  public VenafiTPPFluentImpl() {
  }
  public VenafiTPPFluentImpl(VenafiTPP instance) {
    if (instance != null) {
      this.withCaBundle(instance.getCaBundle());
      this.withCredentialsRef(instance.getCredentialsRef());
      this.withUrl(instance.getUrl());
    }
  }
  private String caBundle;
  private LocalObjectReferenceBuilder credentialsRef;
  private String url;
  public String getCaBundle() {
    return this.caBundle;
  }
  public A withCaBundle(String caBundle) {
    this.caBundle=caBundle; return (A) this;
  }
  public Boolean hasCaBundle() {
    return this.caBundle != null;
  }
  
  /**
   * This method has been deprecated, please use method buildCredentialsRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getCredentialsRef() {
    return this.credentialsRef!=null ?this.credentialsRef.build():null;
  }
  public LocalObjectReference buildCredentialsRef() {
    return this.credentialsRef!=null ?this.credentialsRef.build():null;
  }
  public A withCredentialsRef(LocalObjectReference credentialsRef) {
    _visitables.get("credentialsRef").remove(this.credentialsRef);
    if (credentialsRef!=null){ this.credentialsRef= new LocalObjectReferenceBuilder(credentialsRef); _visitables.get("credentialsRef").add(this.credentialsRef);} else { this.credentialsRef = null; _visitables.get("credentialsRef").remove(this.credentialsRef); } return (A) this;
  }
  public Boolean hasCredentialsRef() {
    return this.credentialsRef != null;
  }
  public A withNewCredentialsRef(String name) {
    return (A)withCredentialsRef(new LocalObjectReference(name));
  }
  public VenafiTPPFluentImpl.CredentialsRefNested<A> withNewCredentialsRef() {
    return new VenafiTPPFluentImpl.CredentialsRefNestedImpl();
  }
  public VenafiTPPFluentImpl.CredentialsRefNested<A> withNewCredentialsRefLike(LocalObjectReference item) {
    return new VenafiTPPFluentImpl.CredentialsRefNestedImpl(item);
  }
  public VenafiTPPFluentImpl.CredentialsRefNested<A> editCredentialsRef() {
    return withNewCredentialsRefLike(getCredentialsRef());
  }
  public VenafiTPPFluentImpl.CredentialsRefNested<A> editOrNewCredentialsRef() {
    return withNewCredentialsRefLike(getCredentialsRef() != null ? getCredentialsRef(): new LocalObjectReferenceBuilder().build());
  }
  public VenafiTPPFluentImpl.CredentialsRefNested<A> editOrNewCredentialsRefLike(LocalObjectReference item) {
    return withNewCredentialsRefLike(getCredentialsRef() != null ? getCredentialsRef(): item);
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VenafiTPPFluentImpl that = (VenafiTPPFluentImpl) o;
    if (!java.util.Objects.equals(caBundle, that.caBundle)) return false;

    if (!java.util.Objects.equals(credentialsRef, that.credentialsRef)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caBundle,  credentialsRef,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (caBundle != null) { sb.append("caBundle:"); sb.append(caBundle + ","); }
    if (credentialsRef != null) { sb.append("credentialsRef:"); sb.append(credentialsRef + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  class CredentialsRefNestedImpl<N> extends LocalObjectReferenceFluentImpl<VenafiTPPFluentImpl.CredentialsRefNested<N>> implements VenafiTPPFluentImpl.CredentialsRefNested<N>,Nested<N>{
    CredentialsRefNestedImpl(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    CredentialsRefNestedImpl() {
      this.builder = new LocalObjectReferenceBuilder(this);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) VenafiTPPFluentImpl.this.withCredentialsRef(builder.build());
    }
    public N endCredentialsRef() {
      return and();
    }
    
  }
  
}
